import com.silanis.esl.sdk.external.signer.verification.domain.request.SignerVerificationRequest;
import com.silanis.esl.sdk.external.signer.verification.domain.request.SignerVerificationRequestPayload;
import com.silanis.esl.sdk.external.signer.verification.domain.signer.SignerInfo;
import com.silanis.esl.sdk.external.signer.verification.domain.transaction.TransactionInfo;
import com.silanis.esl.sdk.external.signer.verification.processor.DefaultSignerVerificationProcessorFactory;
import com.silanis.esl.sdk.external.signer.verification.processor.SignerVerificationConfig;
import com.silanis.esl.sdk.external.signer.verification.processor.SignerVerificationProcessor;
import com.silanis.esl.sdk.external.signer.verification.processor.SignerVerificationProcessorFactory;
import com.silanis.esl.sdk.external.signer.verification.processor.jwt.HmacJwtSignerVerificationConfig;
import com.silanis.esl.sdk.external.signer.verification.url.SignerVerificationRequestUrlBuilder;

import java.net.URISyntaxException;
import java.util.UUID;

public class VerificationRequestTokenGeneration {
    private static final String SIGNING_SHARED_SECRET = "signing secret";
    private static final String ENCRYPTION_SHARED_SECRET = "encryption secret";
    private static final SignerVerificationProcessor signerVerificationProcessor;

    static {
        SignerVerificationConfig signerVerificationConfig = new HmacJwtSignerVerificationConfig(SIGNING_SHARED_SECRET, ENCRYPTION_SHARED_SECRET);
        SignerVerificationProcessorFactory signerVerificationProcessorFactory = new DefaultSignerVerificationProcessorFactory();
        signerVerificationProcessor = signerVerificationProcessorFactory.createSignerVerificationProcessor(signerVerificationConfig);
    }

    public static void main(String[] args) throws URISyntaxException {
        SignerVerificationRequest signerVerificationRequest = new SignerVerificationRequest()
                .setCallbackUrl("https://apps.esignlive.com/transaction/" + UUID.randomUUID().toString() + "/documents/" + UUID.randomUUID().toString())
                .setDocumentIdentificationInfo(UUID.randomUUID().toString())
                .setUserIdentityInfo(UUID.randomUUID().toString())
                .setTransactionInfo(new TransactionInfo()
                        .setTransactionName("Mortgage Application")
                        .setDocumentName("Mortgage Application Form"))
                .setSignerInfo(new SignerInfo()
                        .setSignerEmail("peter.young@yahoo.ca")
                        .setSignerFirstName("Peter")
                        .setSignerLastName("Young"));

        SignerVerificationRequestPayload signerVerificationRequestPayload = signerVerificationProcessor.toSignerVerificationRequestPayload(signerVerificationRequest);
        String redirectURL = new SignerVerificationRequestUrlBuilder()
                .withRootUrl("https://verification.mybank.com")
                .withSignerVerificationRequestPayload(signerVerificationRequestPayload)
                .build();
        System.out.println("Redirecting signer to " + redirectURL);
    }
}
